@@ -10,7 +10,6 @@ import io
 import zipfile
 from nested_lookup import nested_lookup
 import pandas as pd
-import concurrent.futures
 
 
 def execute_nvd_tbl_count():
@@ -117,9 +116,8 @@ def get_nvd_data():
         return True
     else:
         years = ["2023", "2022", "2021", "2020", "2019", "2018"]
-        with concurrent.futures.ThreadPoolExecutor(max_workers=6) as executor:
-            futures = [executor.submit(get_and_load_nvd_file, year) for year in years]
-        concurrent.futures.wait(futures)
+        for year in years:
+            get_and_load_nvd_file(year)
 
 
 def get_and_load_nvd_file(year):
